#!/bin/sh
#
# Functions relating to output.
#
# Copyright 2023-2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

actLastError=""

# Output a standardised error message $1 with optional parameter $2.
#
actError () {
	{
	case "$1" in
	"NO-ACTION")
		errorMessage="no action specified"
		printf "act: %s\n" "${errorMessage}"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNKNOWN-OPTION")
		errorMessage="unknown option"
		printf "act: %s -- '%s'\n" "${errorMessage}" "$2"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNKNOWN-ACTION")
		errorMessage="unknown action"
		printf "act: %s -- '%s'\n" "${errorMessage}" "$2"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNSUPPORTED-ACTION")
		errorMessage="unsupported action on this system"
		printf "act: %s: %s\n" "$2" "${errorMessage}"
		;;
	"MISSING-OPTION-ARGUMENT")
		errorMessage="missing argument for option"
		printf "act: %s: %s\n" "$2" "${errorMessage}"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"MISSING-ARGUMENT")
		errorMessage="missing argument for action"
		printf "act: %s: %s\n" "$2" "${errorMessage}"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNEXPECTED-ARGUMENT")
		errorMessage="action requires no argument"
		printf "act: %s: %s\n" "$2" "${errorMessage}"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"NO-PACKAGE-MANAGER")
		errorMessage="no supported package manager found"
		printf "act: %s\n" "${errorMessage}"
		;;
	"NO-SERVICE-MANAGER")
		errorMessage="no supported service manager found"
		printf "act: %s\n" "${errorMessage}"
		;;
	"UNSUPPORTED-ACTION-FOR-SERVICE")
		errorMessage="specified service does not support this action"
		printf "act: %s: %s: %s\n" "$2" "$3" "${errorMessage}"
		;;
	*)
		errorMessage="$1"
		printf "act: %s\n" "${errorMessage}"
		;;
	esac
	} 1>&2
	actLastError="${errorMessage}"
}


# Output an informational message $1, to standard error, if verbose mode is
# enabled.
#
actInfo () {
	test -n "${optionVerbose}" || return
	test "${optionVerbose}" -gt 0 || return
	printf "act: info: %s\n" "$1" 1>&2
}


# Output a debugging message $1, to standard error, if extra-verbose mode is
# enabled.
#
actDebug () {
	test -n "${optionVerbose}" || return
	test "${optionVerbose}" -gt 1 || return
	printf "act: debug: %s\n" "$1" 1>&2
}

# Preserve stderr as fd 3 so that actRun foo 2>/dev/null can still write
# info to the original stderr.
exec 3>&2

# Run a command; in verbose mode, report what is being run.
#
actRun () {
	actInfo "running: $*" 2>&3
	"$@" 3<&-
	return $?
}
